#!/usr/bin/env python

import argparse
import os
import requests
import sys
import time


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--es-url", required=True, help="The base URL for elasticsearch")
    parser.add_argument("--aws", action="store_true", help="Targeting an Amazon Elasticsearch Service cluster")
    parser.add_argument("--aws-region", default="us-west-2", help="The base URL for elasticsearch")
    parser.add_argument("--wait-timeout", default=60*10, help="Wait timeout in seconds")
    parser.add_argument("--check-interval", default=10, help="How often to check health")
    parser.add_argument("--es-user", required=True, help="User for elasticsearch")
    parser.add_argument("--es-password", default=os.environ.get('ES_PASSWORD'), help="Password for elasticsearch")
    args = parser.parse_args()

    end = time.time() + args.wait_timeout
    url = f"{args.es_url}/_cluster/health"
    print(f"Waiting for {url} to be ready")
    while time.time() < end:
        # Use basic auth for requests

        response = requests.get(f"{args.es_url}/_cluster/health", auth=(args.es_user, args.es_password), verify=False)

        if response.status_code == 200:
            print(f"{args.es_url} is ready!")
            return

        elif response.status_code == 403:
            sys.exit(f"Received a {response.status_code} from {args.es_url} - Terminal")

        print(f"Received a {response.status_code} from {url} - Retrying in {args.check_interval} seconds")
        time.sleep(args.check_interval)

    sys.exit(f"Timeout waiting for {args.es_url}")


if __name__ == "__main__":
    main()
